@@ -15,7 +15,7 @@ pub struct Song {
 
 impl fmt::Display for Song {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "{} - {}", self.title, self.artists.join(", "))
+        write!(f, "{} - {}", self.artists.join(", "), self.title)
     } 
 }
 
